import logging
import unittest

from clarifai.rest import ApiError, ClarifaiApp


class TestAuth(unittest.TestCase):
  """
  unit test for api auth
  """

  _multiprocess_can_split_ = True

  def test_auth_with_invalid_key(self):
    """ instantiate with key """

    api_preset_key = 'abc'
    with self.assertRaises(ApiError):
      ClarifaiApp(api_key=api_preset_key, log_level=logging.WARN)

  def test_auth_with_id_and_secret(self):
    with self.assertRaises(DeprecationWarning):
      ClarifaiApp(app_id='aa', app_secret='bb', log_level=logging.WARN)


if __name__ == '__main__':
  unittest.main()



# -*- coding: utf-8 -*-

import base64
import logging
import os
import unittest

from clarifai.rest import ClarifaiApp, Concept
from clarifai.rest import Image as ClImage
from clarifai.rest import ModelOutputConfig, ModelOutputInfo

METRO_NORTH_IMAGE_URL = "https://samples.clarifai.com/metro-north.jpg"
VIDEO_URL = 'https://samples.clarifai.com/3o6gb3kkXfLvdKEZs4.gif'

METRO_NORTH_IMAGE_FILE_PATH = os.path.join(
    os.path.dirname(os.path.realpath(__file__)), 'data/metro-north.jpg')


class TestPredict(unittest.TestCase):
  _multiprocess_can_split_ = True
  to_cleanup = []

  @classmethod
  def setUpClass(cls):
    cls.app = ClarifaiApp(log_level=logging.WARN)

  def test_predict_image_url(self):
    """ predict a single url """

    # just by url
    m = self.app.models.get('general-v1.3')
    res = m.predict_by_url(METRO_NORTH_IMAGE_URL)
    self.assertEqual(10000, res['status']['code'])
    assert 'railway' in [concept['name'] for concept in res['outputs'][0]['data']['concepts']]

  def test_predict_image_url_min_value(self):

    # url, with min_value
    m = self.app.models.get('general-v1.3')
    res = m.predict_by_url(METRO_NORTH_IMAGE_URL, min_value=0.4)
    self.assertEqual(10000, res['status']['code'])
    for c in res['outputs'][0]['data']['concepts']:
      self.assertGreaterEqual(c['value'], 0.4)

  def test_predict_image_url_max_concepts(self):

    # url, with max_concepts
    m = self.app.models.get('general-v1.3')
    res = m.predict_by_url(METRO_NORTH_IMAGE_URL, max_concepts=5)
    self.assertEqual(10000, res['status']['code'])
    self.assertEqual(len(res['outputs'][0]['data']['concepts']), 5)

  def test_predict_image_url_min_value_max_concepts(self):

    # url, with both min_value and max_concepts
    m = self.app.models.get('general-v1.3')
    res = m.predict_by_url(METRO_NORTH_IMAGE_URL, min_value=0.6, max_concepts=5)
    self.assertEqual(10000, res['status']['code'])
    for c in res['outputs'][0]['data']['concepts']:
      self.assertGreaterEqual(c['value'], 0.6)

    self.assertLessEqual(len(res['outputs'][0]['data']['concepts']), 5)

  def test_predict_image_url_select_concepts(self):

    # url, with select_concepts, by name
    m = self.app.models.get('general-v1.3')
    select_concepts = [Concept(concept_name='beer'), Concept(concept_name='vehicle')]
    res = m.predict_by_url(METRO_NORTH_IMAGE_URL, select_concepts=select_concepts)
    self.assertEqual(10000, res['status']['code'])
    self.assertEqual(len(res['outputs'][0]['data']['concepts']), 2)

    # url, with select_concepts by id
    select_concepts = [
        Concept(concept_id='ai_hK1KnTCJ'),
        Concept(concept_id='ai_m52MdMR3'),
        Concept(concept_id='ai_fN8NZ9JV')
    ]
    res = m.predict_by_url(METRO_NORTH_IMAGE_URL, select_concepts=select_concepts)
    self.assertEqual(10000, res['status']['code'])
    self.assertEqual(len(res['outputs'][0]['data']['concepts']), 3)

  def test_predict_video_url(self):
    """ predict a single url """

    # just by url
    m = self.app.models.get('general-v1.3')
    res = m.predict_by_url(VIDEO_URL, is_video=True)
    self.assertEqual(10000, res['status']['code'])

  def test_predict_video_url_min_value(self):

    # url, with min_value
    m = self.app.models.get('general-v1.3')
    res = m.predict_by_url(VIDEO_URL, is_video=True, min_value=0.9)
    self.assertEqual(10000, res['status']['code'])
    for frame in res['outputs'][0]['data']['frames']:
      for c in frame['data']['concepts']:
        self.assertGreaterEqual(c['value'], 0.9)

  def test_predict_video_url_max_concepts(self):

    # url, with max_concepts
    m = self.app.models.get('general-v1.3')
    res = m.predict_by_url(VIDEO_URL, is_video=True, max_concepts=3)
    self.assertEqual(10000, res['status']['code'])
    for frame in res['outputs'][0]['data']['frames']:
      self.assertEqual(len(frame['data']['concepts']), 3)

  def test_predict_video_url_min_value_max_concepts(self):

    # url, with both min_value and max_concepts
    m = self.app.models.get('general-v1.3')
    res = m.predict_by_url(VIDEO_URL, is_video=True, min_value=0.85, max_concepts=3)
    self.assertEqual(10000, res['status']['code'])
    for frame in res['outputs'][0]['data']['frames']:
      for c in frame['data']['concepts']:
        self.assertGreaterEqual(c['value'], 0.85)

    for frame in res['outputs'][0]['data']['frames']:
      self.assertLessEqual(len(frame['data']['concepts']), 3)

  def test_bulk_with_min_value(self):

    img = ClImage(url=METRO_NORTH_IMAGE_URL)

    m = self.app.models.get('general-v1.3')
    model_output_info = ModelOutputInfo(output_config=ModelOutputConfig(min_value=0.96))

    res = m.predict(inputs=[img, img, img], model_output_info=model_output_info)
    self.assertEqual(10000, res['status']['code'])

    for result in res['outputs']:
      for c in result['data']['concepts']:
        self.assertGreaterEqual(c['value'], 0.96)

  def test_predict_image_by_filename(self):
    """ predict a an image by file name """

    m = self.app.models.get('general-v1.3')
    res = m.predict_by_filename(METRO_NORTH_IMAGE_FILE_PATH)
    self.assertEqual(10000, res['status']['code'])
    assert 'railway' in [concept['name'] for concept in res['outputs'][0]['data']['concepts']]

  def test_predict_image_by_bytes(self):
    """ predict a an image by file name """

    with open(METRO_NORTH_IMAGE_FILE_PATH, 'rb') as f:
      image_bytes = f.read()

    m = self.app.models.get('general-v1.3')
    res = m.predict_by_bytes(image_bytes)
    self.assertEqual(10000, res['status']['code'])
    assert 'railway' in [concept['name'] for concept in res['outputs'][0]['data']['concepts']]

  def test_predict_image_by_base64(self):
    """ predict a an image by file name """

    with open(METRO_NORTH_IMAGE_FILE_PATH, 'rb') as f:
      image_base64 = base64.b64encode(f.read())

    m = self.app.models.get('general-v1.3')
    res = m.predict_by_base64(image_base64)
    self.assertEqual(10000, res['status']['code'])
    assert 'railway' in [concept['name'] for concept in res['outputs'][0]['data']['concepts']]


if __name__ == '__main__':
  unittest.main()



import unittest

from clarifai.rest.grpc.grpc_json_channel import protobuf_to_dict
from clarifai.rest.grpc.proto.clarifai.api.concept_pb2 import Concept as ConceptPB
from clarifai.rest.grpc.proto.clarifai.api.model_pb2 import \
    MultiModelResponse as MultiModelResponsePB
from clarifai.rest.grpc.proto.clarifai.api.status.status_pb2 import Status as StatusPB
from clarifai.rest.grpc.proto.clarifai.api.workflow_pb2 import \
    MultiWorkflowResponse as MultiWorkflowResponsePB


class TestProtobufToJson(unittest.TestCase):
  _multiprocess_can_split_ = True

  def test_concept_with_no_value(self):
    concept = ConceptPB()
    concept.id = 'some-id'
    concept.name = 'Some Name'
    converted = protobuf_to_dict(concept)
    assert converted['value'] == 0.0

  def test_concept_with_value_non_zero(self):
    concept = ConceptPB()
    concept.id = 'some-id'
    concept.name = 'Some Name'
    concept.value = 0.5
    converted = protobuf_to_dict(concept)
    assert converted['value'] == 0.5

  def test_concept_with_value_zero(self):
    concept = ConceptPB()
    concept.id = 'some-id'
    concept.name = 'Some Name'
    concept.value = 0.0
    converted = protobuf_to_dict(concept)
    assert converted['value'] == 0.0

  def test_concept_with_value_one(self):
    concept = ConceptPB()
    concept.id = 'some-id'
    concept.name = 'Some Name'
    concept.value = True
    converted = protobuf_to_dict(concept)
    assert converted['value'] == 1.0

  def test_show_workflows_list_if_empty(self):
    status = StatusPB()
    status.description = 'Some description'

    workflows_response = MultiWorkflowResponsePB()
    workflows_response.status.CopyFrom(status)

    converted = protobuf_to_dict(workflows_response)
    assert (_ordered_json_object(converted) == _ordered_json_object({
        'status': {
            'description': 'Some description'
        },
        'workflows': []
    }))

  def test_show_models_list_if_empty(self):
    status = StatusPB()
    status.description = 'Some description'

    models_response = MultiModelResponsePB()
    models_response.status.CopyFrom(status)

    converted = protobuf_to_dict(models_response)
    assert (_ordered_json_object(converted) == _ordered_json_object({
        'status': {
            'description': 'Some description'
        },
        'models': []
    }))


def _ordered_json_object(obj):
  """ Orders all the keys of the object, recursively. """

  if isinstance(obj, dict):
    return sorted((k, _ordered_json_object(v)) for k, v in obj.items())
  if isinstance(obj, list):
    return sorted(_ordered_json_object(x) for x in obj)
  else:
    return obj



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/common.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/common.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1fproto/clarifai/api/common.proto\x12\x0c\x63larifai.api\"/\n\x0cUserAppIDSet\x12\x0f\n\x07user_id\x18\x01 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x02 \x01(\tB$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
)




_USERAPPIDSET = _descriptor.Descriptor(
  name='UserAppIDSet',
  full_name='clarifai.api.UserAppIDSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_id', full_name='clarifai.api.UserAppIDSet.user_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='clarifai.api.UserAppIDSet.app_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=49,
  serialized_end=96,
)

DESCRIPTOR.message_types_by_name['UserAppIDSet'] = _USERAPPIDSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UserAppIDSet = _reflection.GeneratedProtocolMessageType('UserAppIDSet', (_message.Message,), dict(
  DESCRIPTOR = _USERAPPIDSET,
  __module__ = 'proto.clarifai.api.common_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.UserAppIDSet)
  ))
_sym_db.RegisterMessage(UserAppIDSet)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/visualization.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from clarifai.rest.grpc.proto.clarifai.api import common_pb2 as proto_dot_clarifai_dot_api_dot_common__pb2
from clarifai.rest.grpc.proto.clarifai.api import data_pb2 as proto_dot_clarifai_dot_api_dot_data__pb2
from clarifai.rest.grpc.proto.clarifai.api import input_pb2 as proto_dot_clarifai_dot_api_dot_input__pb2
from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/visualization.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n&proto/clarifai/api/visualization.proto\x12\x0c\x63larifai.api\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1fproto/clarifai/api/common.proto\x1a\x1dproto/clarifai/api/data.proto\x1a\x1eproto/clarifai/api/input.proto\x1a&proto/clarifai/api/status/status.proto\"\xe3\x01\n\x13VisualizationOutput\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06\x61pp_id\x18\x03 \x01(\t\x12\x0c\n\x04type\x18\x04 \x01(\t\x12 \n\x04\x64\x61ta\x18\x05 \x01(\x0b\x32\x12.clarifai.api.Data\x12.\n\ncreated_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12#\n\x06inputs\x18\x07 \x03(\x0b\x32\x13.clarifai.api.Input\"K\n\x18PostVisualizationRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\"d\n\x17GetVisualizationRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x18\n\x10visualization_id\x18\x02 \x01(\t\"M\n\x1aGetAppVisualizationRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\"\x8b\x01\n\x1bSingleVisualizationResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12?\n\x14visualization_output\x18\x02 \x01(\x0b\x32!.clarifai.api.VisualizationOutputB$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_common__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_data__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_input__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.DESCRIPTOR,])




_VISUALIZATIONOUTPUT = _descriptor.Descriptor(
  name='VisualizationOutput',
  full_name='clarifai.api.VisualizationOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.VisualizationOutput.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.VisualizationOutput.id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='app_id', full_name='clarifai.api.VisualizationOutput.app_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='clarifai.api.VisualizationOutput.type', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='clarifai.api.VisualizationOutput.data', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='created_at', full_name='clarifai.api.VisualizationOutput.created_at', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputs', full_name='clarifai.api.VisualizationOutput.inputs', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=453,
)


_POSTVISUALIZATIONREQUEST = _descriptor.Descriptor(
  name='PostVisualizationRequest',
  full_name='clarifai.api.PostVisualizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostVisualizationRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=455,
  serialized_end=530,
)


_GETVISUALIZATIONREQUEST = _descriptor.Descriptor(
  name='GetVisualizationRequest',
  full_name='clarifai.api.GetVisualizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetVisualizationRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='visualization_id', full_name='clarifai.api.GetVisualizationRequest.visualization_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=532,
  serialized_end=632,
)


_GETAPPVISUALIZATIONREQUEST = _descriptor.Descriptor(
  name='GetAppVisualizationRequest',
  full_name='clarifai.api.GetAppVisualizationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetAppVisualizationRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=634,
  serialized_end=711,
)


_SINGLEVISUALIZATIONRESPONSE = _descriptor.Descriptor(
  name='SingleVisualizationResponse',
  full_name='clarifai.api.SingleVisualizationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleVisualizationResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='visualization_output', full_name='clarifai.api.SingleVisualizationResponse.visualization_output', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=714,
  serialized_end=853,
)

_VISUALIZATIONOUTPUT.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_VISUALIZATIONOUTPUT.fields_by_name['data'].message_type = proto_dot_clarifai_dot_api_dot_data__pb2._DATA
_VISUALIZATIONOUTPUT.fields_by_name['created_at'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VISUALIZATIONOUTPUT.fields_by_name['inputs'].message_type = proto_dot_clarifai_dot_api_dot_input__pb2._INPUT
_POSTVISUALIZATIONREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_GETVISUALIZATIONREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_GETAPPVISUALIZATIONREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_SINGLEVISUALIZATIONRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLEVISUALIZATIONRESPONSE.fields_by_name['visualization_output'].message_type = _VISUALIZATIONOUTPUT
DESCRIPTOR.message_types_by_name['VisualizationOutput'] = _VISUALIZATIONOUTPUT
DESCRIPTOR.message_types_by_name['PostVisualizationRequest'] = _POSTVISUALIZATIONREQUEST
DESCRIPTOR.message_types_by_name['GetVisualizationRequest'] = _GETVISUALIZATIONREQUEST
DESCRIPTOR.message_types_by_name['GetAppVisualizationRequest'] = _GETAPPVISUALIZATIONREQUEST
DESCRIPTOR.message_types_by_name['SingleVisualizationResponse'] = _SINGLEVISUALIZATIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VisualizationOutput = _reflection.GeneratedProtocolMessageType('VisualizationOutput', (_message.Message,), dict(
  DESCRIPTOR = _VISUALIZATIONOUTPUT,
  __module__ = 'proto.clarifai.api.visualization_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.VisualizationOutput)
  ))
_sym_db.RegisterMessage(VisualizationOutput)

PostVisualizationRequest = _reflection.GeneratedProtocolMessageType('PostVisualizationRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTVISUALIZATIONREQUEST,
  __module__ = 'proto.clarifai.api.visualization_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostVisualizationRequest)
  ))
_sym_db.RegisterMessage(PostVisualizationRequest)

GetVisualizationRequest = _reflection.GeneratedProtocolMessageType('GetVisualizationRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETVISUALIZATIONREQUEST,
  __module__ = 'proto.clarifai.api.visualization_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetVisualizationRequest)
  ))
_sym_db.RegisterMessage(GetVisualizationRequest)

GetAppVisualizationRequest = _reflection.GeneratedProtocolMessageType('GetAppVisualizationRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETAPPVISUALIZATIONREQUEST,
  __module__ = 'proto.clarifai.api.visualization_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetAppVisualizationRequest)
  ))
_sym_db.RegisterMessage(GetAppVisualizationRequest)

SingleVisualizationResponse = _reflection.GeneratedProtocolMessageType('SingleVisualizationResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLEVISUALIZATIONRESPONSE,
  __module__ = 'proto.clarifai.api.visualization_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleVisualizationResponse)
  ))
_sym_db.RegisterMessage(SingleVisualizationResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/subscription.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/subscription.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n%proto/clarifai/api/subscription.proto\x12\x0c\x63larifai.api\x1a&proto/clarifai/api/status/status.proto\"\x14\n\x04Plan\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x18\n\x16GetSubscriptionRequest\"P\n\x17PostSubscriptionRequest\x12\x13\n\x0bsignup_code\x18\x01 \x01(\t\x12 \n\x04plan\x18\x02 \x01(\x0b\x32\x12.clarifai.api.Plan\"\x80\x01\n\x1aSingleSubscriptionResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12 \n\x04plan\x18\x02 \x01(\x0b\x32\x12.clarifai.api.Plan\x12\x13\n\x0bsignup_code\x18\x03 \x01(\tB$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.DESCRIPTOR,])




_PLAN = _descriptor.Descriptor(
  name='Plan',
  full_name='clarifai.api.Plan',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='clarifai.api.Plan.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=95,
  serialized_end=115,
)


_GETSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='GetSubscriptionRequest',
  full_name='clarifai.api.GetSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=117,
  serialized_end=141,
)


_POSTSUBSCRIPTIONREQUEST = _descriptor.Descriptor(
  name='PostSubscriptionRequest',
  full_name='clarifai.api.PostSubscriptionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signup_code', full_name='clarifai.api.PostSubscriptionRequest.signup_code', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plan', full_name='clarifai.api.PostSubscriptionRequest.plan', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=223,
)


_SINGLESUBSCRIPTIONRESPONSE = _descriptor.Descriptor(
  name='SingleSubscriptionResponse',
  full_name='clarifai.api.SingleSubscriptionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleSubscriptionResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plan', full_name='clarifai.api.SingleSubscriptionResponse.plan', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signup_code', full_name='clarifai.api.SingleSubscriptionResponse.signup_code', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=354,
)

_POSTSUBSCRIPTIONREQUEST.fields_by_name['plan'].message_type = _PLAN
_SINGLESUBSCRIPTIONRESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLESUBSCRIPTIONRESPONSE.fields_by_name['plan'].message_type = _PLAN
DESCRIPTOR.message_types_by_name['Plan'] = _PLAN
DESCRIPTOR.message_types_by_name['GetSubscriptionRequest'] = _GETSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['PostSubscriptionRequest'] = _POSTSUBSCRIPTIONREQUEST
DESCRIPTOR.message_types_by_name['SingleSubscriptionResponse'] = _SINGLESUBSCRIPTIONRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Plan = _reflection.GeneratedProtocolMessageType('Plan', (_message.Message,), dict(
  DESCRIPTOR = _PLAN,
  __module__ = 'proto.clarifai.api.subscription_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.Plan)
  ))
_sym_db.RegisterMessage(Plan)

GetSubscriptionRequest = _reflection.GeneratedProtocolMessageType('GetSubscriptionRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSUBSCRIPTIONREQUEST,
  __module__ = 'proto.clarifai.api.subscription_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetSubscriptionRequest)
  ))
_sym_db.RegisterMessage(GetSubscriptionRequest)

PostSubscriptionRequest = _reflection.GeneratedProtocolMessageType('PostSubscriptionRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTSUBSCRIPTIONREQUEST,
  __module__ = 'proto.clarifai.api.subscription_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostSubscriptionRequest)
  ))
_sym_db.RegisterMessage(PostSubscriptionRequest)

SingleSubscriptionResponse = _reflection.GeneratedProtocolMessageType('SingleSubscriptionResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLESUBSCRIPTIONRESPONSE,
  __module__ = 'proto.clarifai.api.subscription_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleSubscriptionResponse)
  ))
_sym_db.RegisterMessage(SingleSubscriptionResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/concept_language.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clarifai.rest.grpc.proto.clarifai.api import common_pb2 as proto_dot_clarifai_dot_api_dot_common__pb2
from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2
from clarifai.rest.grpc.proto.clarifai.api.utils import extensions_pb2 as proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/concept_language.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n)proto/clarifai/api/concept_language.proto\x12\x0c\x63larifai.api\x1a\x1fproto/clarifai/api/common.proto\x1a&proto/clarifai/api/status/status.proto\x1a)proto/clarifai/api/utils/extensions.proto\"?\n\x0f\x43onceptLanguage\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\ndefinition\x18\x03 \x01(\t\"r\n\x19GetConceptLanguageRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x12\n\nconcept_id\x18\x02 \x01(\t\x12\x10\n\x08language\x18\x03 \x01(\t\"\x82\x01\n\x1bListConceptLanguagesRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x12\n\nconcept_id\x18\x02 \x01(\t\x12\x0c\n\x04page\x18\x03 \x01(\r\x12\x10\n\x08per_page\x18\x04 \x01(\r\"\xad\x01\n\x1cPatchConceptLanguagesRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x12\n\nconcept_id\x18\x02 \x01(\t\x12\x38\n\x11\x63oncept_languages\x18\x03 \x03(\x0b\x32\x1d.clarifai.api.ConceptLanguage\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t\"\x9c\x01\n\x1bPostConceptLanguagesRequest\x12/\n\x0buser_app_id\x18\x01 \x01(\x0b\x32\x1a.clarifai.api.UserAppIDSet\x12\x12\n\nconcept_id\x18\x02 \x01(\t\x12\x38\n\x11\x63oncept_languages\x18\x03 \x03(\x0b\x32\x1d.clarifai.api.ConceptLanguage\"\x85\x01\n\x1dSingleConceptLanguageResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12\x37\n\x10\x63oncept_language\x18\x02 \x01(\x0b\x32\x1d.clarifai.api.ConceptLanguage\"\x8b\x01\n\x1cMultiConceptLanguageResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12>\n\x11\x63oncept_languages\x18\x02 \x03(\x0b\x32\x1d.clarifai.api.ConceptLanguageB\x04\x80\xb5\x18\x01\x42$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[proto_dot_clarifai_dot_api_dot_common__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.DESCRIPTOR,proto_dot_clarifai_dot_api_dot_utils_dot_extensions__pb2.DESCRIPTOR,])




_CONCEPTLANGUAGE = _descriptor.Descriptor(
  name='ConceptLanguage',
  full_name='clarifai.api.ConceptLanguage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='clarifai.api.ConceptLanguage.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='clarifai.api.ConceptLanguage.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='definition', full_name='clarifai.api.ConceptLanguage.definition', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=175,
  serialized_end=238,
)


_GETCONCEPTLANGUAGEREQUEST = _descriptor.Descriptor(
  name='GetConceptLanguageRequest',
  full_name='clarifai.api.GetConceptLanguageRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.GetConceptLanguageRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_id', full_name='clarifai.api.GetConceptLanguageRequest.concept_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language', full_name='clarifai.api.GetConceptLanguageRequest.language', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=240,
  serialized_end=354,
)


_LISTCONCEPTLANGUAGESREQUEST = _descriptor.Descriptor(
  name='ListConceptLanguagesRequest',
  full_name='clarifai.api.ListConceptLanguagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.ListConceptLanguagesRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_id', full_name='clarifai.api.ListConceptLanguagesRequest.concept_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='page', full_name='clarifai.api.ListConceptLanguagesRequest.page', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_page', full_name='clarifai.api.ListConceptLanguagesRequest.per_page', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=357,
  serialized_end=487,
)


_PATCHCONCEPTLANGUAGESREQUEST = _descriptor.Descriptor(
  name='PatchConceptLanguagesRequest',
  full_name='clarifai.api.PatchConceptLanguagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PatchConceptLanguagesRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_id', full_name='clarifai.api.PatchConceptLanguagesRequest.concept_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_languages', full_name='clarifai.api.PatchConceptLanguagesRequest.concept_languages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='action', full_name='clarifai.api.PatchConceptLanguagesRequest.action', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=490,
  serialized_end=663,
)


_POSTCONCEPTLANGUAGESREQUEST = _descriptor.Descriptor(
  name='PostConceptLanguagesRequest',
  full_name='clarifai.api.PostConceptLanguagesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='user_app_id', full_name='clarifai.api.PostConceptLanguagesRequest.user_app_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_id', full_name='clarifai.api.PostConceptLanguagesRequest.concept_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_languages', full_name='clarifai.api.PostConceptLanguagesRequest.concept_languages', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=666,
  serialized_end=822,
)


_SINGLECONCEPTLANGUAGERESPONSE = _descriptor.Descriptor(
  name='SingleConceptLanguageResponse',
  full_name='clarifai.api.SingleConceptLanguageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleConceptLanguageResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_language', full_name='clarifai.api.SingleConceptLanguageResponse.concept_language', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=825,
  serialized_end=958,
)


_MULTICONCEPTLANGUAGERESPONSE = _descriptor.Descriptor(
  name='MultiConceptLanguageResponse',
  full_name='clarifai.api.MultiConceptLanguageResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.MultiConceptLanguageResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='concept_languages', full_name='clarifai.api.MultiConceptLanguageResponse.concept_languages', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=_descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001')), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=961,
  serialized_end=1100,
)

_GETCONCEPTLANGUAGEREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_LISTCONCEPTLANGUAGESREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_PATCHCONCEPTLANGUAGESREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_PATCHCONCEPTLANGUAGESREQUEST.fields_by_name['concept_languages'].message_type = _CONCEPTLANGUAGE
_POSTCONCEPTLANGUAGESREQUEST.fields_by_name['user_app_id'].message_type = proto_dot_clarifai_dot_api_dot_common__pb2._USERAPPIDSET
_POSTCONCEPTLANGUAGESREQUEST.fields_by_name['concept_languages'].message_type = _CONCEPTLANGUAGE
_SINGLECONCEPTLANGUAGERESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_SINGLECONCEPTLANGUAGERESPONSE.fields_by_name['concept_language'].message_type = _CONCEPTLANGUAGE
_MULTICONCEPTLANGUAGERESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MULTICONCEPTLANGUAGERESPONSE.fields_by_name['concept_languages'].message_type = _CONCEPTLANGUAGE
DESCRIPTOR.message_types_by_name['ConceptLanguage'] = _CONCEPTLANGUAGE
DESCRIPTOR.message_types_by_name['GetConceptLanguageRequest'] = _GETCONCEPTLANGUAGEREQUEST
DESCRIPTOR.message_types_by_name['ListConceptLanguagesRequest'] = _LISTCONCEPTLANGUAGESREQUEST
DESCRIPTOR.message_types_by_name['PatchConceptLanguagesRequest'] = _PATCHCONCEPTLANGUAGESREQUEST
DESCRIPTOR.message_types_by_name['PostConceptLanguagesRequest'] = _POSTCONCEPTLANGUAGESREQUEST
DESCRIPTOR.message_types_by_name['SingleConceptLanguageResponse'] = _SINGLECONCEPTLANGUAGERESPONSE
DESCRIPTOR.message_types_by_name['MultiConceptLanguageResponse'] = _MULTICONCEPTLANGUAGERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ConceptLanguage = _reflection.GeneratedProtocolMessageType('ConceptLanguage', (_message.Message,), dict(
  DESCRIPTOR = _CONCEPTLANGUAGE,
  __module__ = 'proto.clarifai.api.concept_language_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ConceptLanguage)
  ))
_sym_db.RegisterMessage(ConceptLanguage)

GetConceptLanguageRequest = _reflection.GeneratedProtocolMessageType('GetConceptLanguageRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETCONCEPTLANGUAGEREQUEST,
  __module__ = 'proto.clarifai.api.concept_language_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetConceptLanguageRequest)
  ))
_sym_db.RegisterMessage(GetConceptLanguageRequest)

ListConceptLanguagesRequest = _reflection.GeneratedProtocolMessageType('ListConceptLanguagesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTCONCEPTLANGUAGESREQUEST,
  __module__ = 'proto.clarifai.api.concept_language_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ListConceptLanguagesRequest)
  ))
_sym_db.RegisterMessage(ListConceptLanguagesRequest)

PatchConceptLanguagesRequest = _reflection.GeneratedProtocolMessageType('PatchConceptLanguagesRequest', (_message.Message,), dict(
  DESCRIPTOR = _PATCHCONCEPTLANGUAGESREQUEST,
  __module__ = 'proto.clarifai.api.concept_language_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PatchConceptLanguagesRequest)
  ))
_sym_db.RegisterMessage(PatchConceptLanguagesRequest)

PostConceptLanguagesRequest = _reflection.GeneratedProtocolMessageType('PostConceptLanguagesRequest', (_message.Message,), dict(
  DESCRIPTOR = _POSTCONCEPTLANGUAGESREQUEST,
  __module__ = 'proto.clarifai.api.concept_language_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.PostConceptLanguagesRequest)
  ))
_sym_db.RegisterMessage(PostConceptLanguagesRequest)

SingleConceptLanguageResponse = _reflection.GeneratedProtocolMessageType('SingleConceptLanguageResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLECONCEPTLANGUAGERESPONSE,
  __module__ = 'proto.clarifai.api.concept_language_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleConceptLanguageResponse)
  ))
_sym_db.RegisterMessage(SingleConceptLanguageResponse)

MultiConceptLanguageResponse = _reflection.GeneratedProtocolMessageType('MultiConceptLanguageResponse', (_message.Message,), dict(
  DESCRIPTOR = _MULTICONCEPTLANGUAGERESPONSE,
  __module__ = 'proto.clarifai.api.concept_language_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.MultiConceptLanguageResponse)
  ))
_sym_db.RegisterMessage(MultiConceptLanguageResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
_MULTICONCEPTLANGUAGERESPONSE.fields_by_name['concept_languages'].has_options = True
_MULTICONCEPTLANGUAGERESPONSE.fields_by_name['concept_languages']._options = _descriptor._ParseOptions(descriptor_pb2.FieldOptions(), _b('\200\265\030\001'))
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
"""
Test for feedback API endpoints
"""

import logging
import unittest

from clarifai.rest import (BoundingBox, ClarifaiApp, Concept, Face, FaceAgeAppearance,
                           FaceGenderAppearance, FaceIdentity, FaceMulticulturalAppearance,
                           FeedbackInfo, FeedbackType, Region, RegionInfo)


class TestFeedback(unittest.TestCase):
  _multiprocess_can_split_ = True
  to_cleanup = []

  @classmethod
  def setUpClass(cls):
    cls.app = ClarifaiApp(log_level=logging.WARN)

  def test_send_concept_feedback(self):
    """ send concept feedback to models """

    feedback_info = FeedbackInfo(
        end_user_id='robert_python_test_key',
        session_id='sessionSS',
        event_type='annotation',
        output_id='oooooooid')

    m = self.app.models.get('general-v1.3')

    ret = m.send_concept_feedback(
        input_id='bb',
        url='https://samples.clarifai.com/dog2.jpeg',
        concepts=['dog', 'puppy'],
        not_concepts=['cat', 'tiger'],
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

    ret = m.send_concept_feedback(
        input_id='bb',
        url='https://samples.clarifai.com/dog2.jpeg',
        concepts=['dog', 'puppy'],
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

    ret = m.send_concept_feedback(
        input_id='bb',
        url='https://samples.clarifai.com/dog2.jpeg',
        not_concepts=['cat'],
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

  def test_send_region_feedback(self):
    """ send region feedback with concepts """

    feedback_info = FeedbackInfo(
        end_user_id='robert_python_test_key',
        session_id='from_your_browser',
        event_type='annotation',
        output_id='oooooooid')

    m = self.app.models.get('general-v1.3')

    concepts = [Concept(concept_id='ab', value=False)]
    regions = [
        Region(
            RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.7, 0.8), feedback_type='accurate'),
            concepts=concepts)
    ]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        concepts=['matid2'],
        not_concepts=['lambo'],
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

    concepts = [Concept(concept_id='ab', value=False), Concept(concept_id='bb', value=True)]
    regions = [
        Region(RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.7, 0.8)), concepts=concepts),
        Region(RegionInfo(bbox=BoundingBox(0.1, 0.2, 0.8, 0.85)), concepts=concepts)
    ]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        concepts=['matid2'],
        not_concepts=['lambo'],
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

  def test_send_different_region_feedbacks(self):
    """ send different kind of region feedbacks
        - accurate
        - misplaced
        - not_detected
        - false_positive
    """
    feedback_info = FeedbackInfo(
        end_user_id='robert_python_test_key',
        session_id='from_your_browser',
        event_type='annotation',
        output_id='oooooooid')

    m = self.app.models.get('general-v1.3')

    # positive
    concepts = [Concept(concept_id='ab', value=False)]
    regions = [
        Region(
            RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.7, 0.8), feedback_type='accurate'),
            concepts=concepts)
    ]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        concepts=['matid2'],
        not_concepts=['lambo'],
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

    # misplaced
    regions = [
        Region(
            RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.8, 0.9), feedback_type='misplaced'),
            concepts=concepts)
    ]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        concepts=['matid2'],
        not_concepts=['lambo'],
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

    # misplaced
    regions = [
        Region(
            RegionInfo(bbox=BoundingBox(0.1, 0.2, 0.4, 0.5), feedback_type='not_detected'),
            concepts=concepts)
    ]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        concepts=['matid2'],
        not_concepts=['lambo'],
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

    # false_positive
    regions = [
        Region(
            RegionInfo(bbox=BoundingBox(0.1, 0.2, 0.4, 0.5), feedback_type='false_positive'),
            concepts=concepts)
    ]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        concepts=['matid2'],
        not_concepts=['lambo'],
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

  def test_send_different_region_feedbacks_with_enum_vars(self):
    """ send different kind of region feedbacks with enums
        - accurate
        - misplaced
        - not_detected
        - false_positive
    """
    feedback_info = FeedbackInfo(
        end_user_id='robert_python_test_key',
        session_id='from_your_browser',
        event_type='annotation',
        output_id='oooooooid')

    m = self.app.models.get('general-v1.3')

    # positive
    concepts = [Concept(concept_id='ab', value=False)]
    regions = [
        Region(
            RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.7, 0.8), feedback_type=FeedbackType.accurate),
            concepts=concepts)
    ]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        concepts=['matid2'],
        not_concepts=['lambo'],
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

    # misplaced
    regions = [
        Region(
            RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.8, 0.9), feedback_type=FeedbackType.misplaced),
            concepts=concepts)
    ]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        concepts=['matid2'],
        not_concepts=['lambo'],
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

    # misplaced
    regions = [
        Region(
            RegionInfo(
                bbox=BoundingBox(0.1, 0.2, 0.4, 0.5), feedback_type=FeedbackType.not_detected),
            concepts=concepts)
    ]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        concepts=['matid2'],
        not_concepts=['lambo'],
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

    # false_positive
    regions = [
        Region(
            RegionInfo(
                bbox=BoundingBox(0.1, 0.2, 0.4, 0.5), feedback_type=FeedbackType.false_positive),
            concepts=concepts)
    ]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        concepts=['matid2'],
        not_concepts=['lambo'],
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

  def test_send_age_feedback(self):
    """ send face feedback """

    feedback_info = FeedbackInfo(
        end_user_id='robert_python_test_key',
        session_id='from_your_browser',
        event_type='annotation',
        output_id='oooooooid')

    m = self.app.models.get('general-v1.3')

    identities = [Concept(concept_id='xx', value=True), Concept(concept_id='x2', value=False)]
    ages = [Concept(concept_id='1', value=True)]
    face = Face(identity=FaceIdentity(identities), age_appearance=FaceAgeAppearance(ages))

    regions = [Region(RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.7, 0.8)), face=face)]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

    # send multiple items
    identities = [
        Concept(concept_id='xx', value=True),
        Concept(concept_id='x2', value=False),
        Concept(concept_id='x4', value=True)
    ]
    ages = [Concept(concept_id='1', value=True), Concept(concept_id='2', value=False)]
    face = Face(identity=FaceIdentity(identities), age_appearance=FaceAgeAppearance(ages))

    regions = [Region(RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.7, 0.8)), face=face)]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

  def test_send_gender_feedback(self):
    """ send face feedback """

    feedback_info = FeedbackInfo(
        end_user_id='robert_python_test_key',
        session_id='from_your_browser',
        event_type='annotation',
        output_id='oooooooid')

    m = self.app.models.get('general-v1.3')

    identities = [Concept(concept_id='xx', value=True), Concept(concept_id='x2', value=False)]
    genders = [Concept(concept_id='male', value=True), Concept(concept_id='female', value=False)]
    face = Face(identity=FaceIdentity(identities), gender_appearance=FaceGenderAppearance(genders))

    regions = [Region(RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.7, 0.8)), face=face)]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

  def test_send_multicultural_feedback(self):
    """ send face feedback """

    feedback_info = FeedbackInfo(
        end_user_id='robert_python_test_key',
        session_id='from_your_browser',
        event_type='annotation',
        output_id='oooooooid')

    m = self.app.models.get('general-v1.3')

    identities = [Concept(concept_id='xx', value=True), Concept(concept_id='x2', value=False)]
    cultures = [
        Concept(concept_id='american', value=True),
        Concept(concept_id='asian', value=False)
    ]
    face = Face(
        identity=FaceIdentity(identities),
        multicultural_appearance=FaceMulticulturalAppearance(cultures))

    regions = [Region(RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.7, 0.8)), face=face)]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

  def test_send_complete_multicultural_feedback(self):
    """ send face feedback """

    feedback_info = FeedbackInfo(
        end_user_id='robert_python_test_key',
        session_id='from_your_browser',
        event_type='annotation',
        output_id='oooooooid')

    m = self.app.models.get('general-v1.3')

    identities = [Concept(concept_id='xx', value=True), Concept(concept_id='x2', value=False)]
    ages = [Concept(concept_id='1', value=True), Concept(concept_id='2', value=False)]
    genders = [Concept(concept_id='male', value=True), Concept(concept_id='female', value=False)]
    cultures = [
        Concept(concept_id='american', value=True),
        Concept(concept_id='asian', value=False)
    ]

    face = Face(
        identity=FaceIdentity(identities),
        age_appearance=FaceAgeAppearance(ages),
        gender_appearance=FaceGenderAppearance(genders),
        multicultural_appearance=FaceMulticulturalAppearance(cultures))

    regions = [Region(RegionInfo(bbox=BoundingBox(0.3, 0.2, 0.7, 0.8)), face=face)]

    ret = m.send_region_feedback(
        input_id='xyz',
        url='https://samples.clarifai.com/dog.tiff',
        regions=regions,
        feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)

  def test_send_search_feedback(self):
    """ send search feedback """

    feedback_info = FeedbackInfo(
        end_user_id='robert_python_test_key',
        session_id='from_your_browser',
        event_type='search_click',
        search_id='searchID')

    ret = self.app.inputs.send_search_feedback(input_id='xyz', feedback_info=feedback_info)
    self.assertEqual(ret['status']['code'], 10000)


if __name__ == '__main__':
  unittest.main()



# -*- coding: utf-8 -*-

import unittest

from clarifai.rest import ClarifaiApp, Workflow

urls = [
    "https://samples.clarifai.com/metro-north.jpg",
    "https://samples.clarifai.com/wedding.jpg",
]


class TestWorkflows(unittest.TestCase):
  """
  unit test for workflow related calls
  """

  _multiprocess_can_split_ = True

  @classmethod
  def setUpClass(cls):
    cls.app = ClarifaiApp(quiet=True)

  def test_list_and_get_workflows(self):
    for wf in self.app.workflows.get_all():
      self.assertTrue(isinstance(wf, Workflow))
      wf_get = self.app.workflows.get(wf.wf_id)
      self.assertEqual(wf_get.wf_id, wf.wf_id)

  def test_list_and_get_public_workflows(self):
    for wf in self.app.workflows.get_all(public_only=True):
      self.assertTrue(isinstance(wf, Workflow))
      wf_get = self.app.workflows.get(wf.wf_id)
      self.assertEqual(wf_get.wf_id, wf.wf_id)

  def test_public_workflow_predict(self):

    wf = self.app.workflows.get('General')
    res = wf.predict_by_url(urls[0])
    self.assertEqual(10000, res['status']['code'])

  def test_predict_workflow(self):
    # TODO(Rok) MEDIUM: Make a custom workflow so this test can be written.
    pass


if __name__ == '__main__':
  unittest.main()



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: proto/clarifai/api/code.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from clarifai.rest.grpc.proto.clarifai.api.status import status_pb2 as proto_dot_clarifai_dot_api_dot_status_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='proto/clarifai/api/code.proto',
  package='clarifai.api',
  syntax='proto3',
  serialized_pb=_b('\n\x1dproto/clarifai/api/code.proto\x12\x0c\x63larifai.api\x1a&proto/clarifai/api/status/status.proto\".\n\x14GetStatusCodeRequest\x12\x16\n\x0estatus_code_id\x18\x01 \x01(\t\"\x18\n\x16ListStatusCodesRequest\"G\n\x18SingleStatusCodeResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\"u\n\x17MultiStatusCodeResponse\x12+\n\x06status\x18\x01 \x01(\x0b\x32\x1b.clarifai.api.status.Status\x12-\n\x08statuses\x18\x02 \x03(\x0b\x32\x1b.clarifai.api.status.StatusB$Z\x03\x61pi\xa2\x02\x04\x43\x41IP\xc2\x02\x01_\xca\x02\x11\x43larifai\\Internalb\x06proto3')
  ,
  dependencies=[proto_dot_clarifai_dot_api_dot_status_dot_status__pb2.DESCRIPTOR,])




_GETSTATUSCODEREQUEST = _descriptor.Descriptor(
  name='GetStatusCodeRequest',
  full_name='clarifai.api.GetStatusCodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status_code_id', full_name='clarifai.api.GetStatusCodeRequest.status_code_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=87,
  serialized_end=133,
)


_LISTSTATUSCODESREQUEST = _descriptor.Descriptor(
  name='ListStatusCodesRequest',
  full_name='clarifai.api.ListStatusCodesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=135,
  serialized_end=159,
)


_SINGLESTATUSCODERESPONSE = _descriptor.Descriptor(
  name='SingleStatusCodeResponse',
  full_name='clarifai.api.SingleStatusCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.SingleStatusCodeResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=161,
  serialized_end=232,
)


_MULTISTATUSCODERESPONSE = _descriptor.Descriptor(
  name='MultiStatusCodeResponse',
  full_name='clarifai.api.MultiStatusCodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='clarifai.api.MultiStatusCodeResponse.status', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statuses', full_name='clarifai.api.MultiStatusCodeResponse.statuses', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=234,
  serialized_end=351,
)

_SINGLESTATUSCODERESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MULTISTATUSCODERESPONSE.fields_by_name['status'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
_MULTISTATUSCODERESPONSE.fields_by_name['statuses'].message_type = proto_dot_clarifai_dot_api_dot_status_dot_status__pb2._STATUS
DESCRIPTOR.message_types_by_name['GetStatusCodeRequest'] = _GETSTATUSCODEREQUEST
DESCRIPTOR.message_types_by_name['ListStatusCodesRequest'] = _LISTSTATUSCODESREQUEST
DESCRIPTOR.message_types_by_name['SingleStatusCodeResponse'] = _SINGLESTATUSCODERESPONSE
DESCRIPTOR.message_types_by_name['MultiStatusCodeResponse'] = _MULTISTATUSCODERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetStatusCodeRequest = _reflection.GeneratedProtocolMessageType('GetStatusCodeRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSTATUSCODEREQUEST,
  __module__ = 'proto.clarifai.api.code_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.GetStatusCodeRequest)
  ))
_sym_db.RegisterMessage(GetStatusCodeRequest)

ListStatusCodesRequest = _reflection.GeneratedProtocolMessageType('ListStatusCodesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTSTATUSCODESREQUEST,
  __module__ = 'proto.clarifai.api.code_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.ListStatusCodesRequest)
  ))
_sym_db.RegisterMessage(ListStatusCodesRequest)

SingleStatusCodeResponse = _reflection.GeneratedProtocolMessageType('SingleStatusCodeResponse', (_message.Message,), dict(
  DESCRIPTOR = _SINGLESTATUSCODERESPONSE,
  __module__ = 'proto.clarifai.api.code_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.SingleStatusCodeResponse)
  ))
_sym_db.RegisterMessage(SingleStatusCodeResponse)

MultiStatusCodeResponse = _reflection.GeneratedProtocolMessageType('MultiStatusCodeResponse', (_message.Message,), dict(
  DESCRIPTOR = _MULTISTATUSCODERESPONSE,
  __module__ = 'proto.clarifai.api.code_pb2'
  # @@protoc_insertion_point(class_scope:clarifai.api.MultiStatusCodeResponse)
  ))
_sym_db.RegisterMessage(MultiStatusCodeResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('Z\003api\242\002\004CAIP\302\002\001_\312\002\021Clarifai\\Internal'))
# @@protoc_insertion_point(module_scope)
